import { ChartCompType } from "./lib/Table2Chart/const/chartCompType.ts";
import { mapHeight, mapWidth } from "./lib/Table2Chart/funcs/mapGEOStyle.ts";

const sampleForLineCharts = {
  type: ChartCompType.EChartsBar,
  category: ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"],
  data: [120, 200, 150, 80, 70, 110, 130],
};

const sampleForPieCharts = {
  type: ChartCompType.EChartsPieCenterText,
  radius: ["60%", "90%"],
  title: "示例图表",
  data: [
    { name: "类型一", color: "#ffaacc", value: 100 },
    { name: "类型二", color: "#abc001", value: 200 },
    { name: "类型三", color: "#cad13c", value: 50 },
  ],
};

const bottomCenterTextCharts = {
  title: "奇特上下排位图表",
  columns: 4,
  chartData: Array(12)
    .fill(2)
    .map(() => ({
      type: ChartCompType.EchartsPieBottomCenterText,
      radius: ["60%", "90%"],
      chartWidth: () => mapWidth(120),
      chartHeight: () => mapHeight(120),
      title: "示例图表",
      data: [
        { name: "类型一", color: "#ffaacc", value: 100 },
        { name: "类型二", color: "#abc001", value: 200 },
        { name: "类型三", color: "#cad13c", value: 50 },
      ],
      bottomText: "奇特数据呢!",
    })),
};

const indexMapper: Record<string, any> = {
  7: bottomCenterTextCharts,
  3: {
    title: "简单数字内容显示",
    columns: 2,
    chartData: Array(2)
      .fill(1)
      .map(() => ({
        title: 15,
        bottomText: "奇特数据",
        type: ChartCompType.BottomCenterText,
      })),
  },
  2: {
    title: "混编数据",
    columns: 2,
    chartData: [
      {
        type: ChartCompType.BottomCenterText,
        title: 100,
        bottomText: "奇特数据",
      },
      {
        type: ChartCompType.EChartsPieCenterText,
        radius: ["60%", "90%"],
        title: "示例图表",
        data: [
          { name: "类型一", color: "#ffaacc", value: 100 },
          { name: "类型二", color: "#abc001", value: 200 },
          { name: "类型三", color: "#cad13c", value: 50 },
        ],
      },
    ],
  },
  4: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForLineCharts],
  },
  0: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForPieCharts],
  },
  5: {
    title: "啊哈哈表格呢",
    columns: 1,
    chartData: [
      {
        type: ChartCompType.SimpleTable,
        columns: [
          { key: "a", title: "种类一" },
          { key: "b", title: "种类二" },
          { key: "c", title: "中类似" },
          { key: "d", title: "奇特呢" },
        ],
        data: Array(20)
          .fill(1)
          .map(() => {
            return {
              a: 12,
              b: 123,
              c: 434,
              d: 3123,
            };
          }),
      },
    ],
  },
  1: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForPieCharts],
  },
  6: {
    title: "简单混排图",
    chartData: [sampleForLineCharts, sampleForPieCharts],
  },
};

const layout = [
  { x: 0, y: 0, w: 4, h: 1 },
  { x: 4, y: 0, w: 8, h: 1 },
  { x: 0, y: 2, w: 2, h: 1 },
  { x: 2, y: 2, w: 2, h: 1 },
  { x: 4, y: 2, w: 3, h: 1 },
  { x: 7, y: 1, w: 5, h: 4 },
  { x: 0, y: 1, w: 7, h: 1 },
  { x: 0, y: 3, w: 7, h: 2 },
].map((a, q) => ({
  ...a,
  ...indexMapper[q],
}));

export { layout };
