import { VNode } from "vue";
import { ChartCompType } from "../const/chartCompType.ts";

export type BarChartOptions = {
  category: string[];
  data: number[] | { name: string; data: number[] }[];
  type: ChartCompType;
  chartWidth?: number | string;
  chartHeight?: number | string;
};

export type PieChartOptionsBase = {
  type: ChartCompType;
  radius: Array<string>;
  data: Array<{ value: number; name: string; color: string }>;
  chartWidth?: number | string;
  chartHeight?: number | string;
  legend?: any;
};

export type PieCharOptions = PieChartOptionsBase & {
  title: string;
};

export type PieCharOptionsForBottomCenterText = PieCharOptions & {
  bottomText: string;
};

export type BottonCenterText = {
  title: string;
  bottomTex: string;
  type: ChartCompType;
};

export type SimpleTableChart = {
  type: ChartCompType;
  columns: Array<{ title: string; key: string }>;
  data: Array<Record<string, any>>;
};

export type GeneralChartOptions =
  | BarChartOptions
  | PieCharOptions
  | PieCharOptionsForBottomCenterText
  | BottonCenterText
  | SimpleTableChart;

export type ChartOptionSet = Array<GeneralChartOptions>;

export type SingleLayoutConf = {
  x: number;
  y: number;
  w: number;
  h: number;
  title: string;
  renderTitle?: (...args: any[]) => VNode;
  chartData: ChartOptionSet;
  wrapperClass?: string | Array<string> | Record<string, any>;
  wrapperStyle?: Record<string, any> | Function;
  columns?: number;
};

export type LayoutConfig = Array<SingleLayoutConf>;

export type ScreenChartProps = {
  layout: LayoutConfig;
  gap?: number;
  containerPadding?: number;
  gridItemPadding?: number;
};
